@@ -51,7 +51,8 @@ estPlotTriple <- function(x,col="black",highlight=NULL,hlCol="red",pch=20,zoom=F
     for(yRun in (xRun+1):Nprobs)
     {
       if(xRun==1 & yRun == 2) par(oma=c(0,3,3,0), mar=c(0,0,0,0))
-      if(xRun==(Nprobs-1) & yRun == Nprobs) par(bty="o")
+#       if(xRun==(Nprobs-1) & yRun == Nprobs) par(bty="o")
+      ifelse(yRun==(Nprobs), par(bty="o"),par(bty="c"))
 
       xValues <- getTripleProb(x,tripleComb[run,4],tripleComb[run,5],tripleComb[run,6])
       xMin <- ifelse(zoom,min(xValues),0)
